@@ -1,10 +1,13 @@
-use Archive::Zip;
+package Archive::Zip::Tree;
 
+use strict;
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.22';
+	$VERSION = '1.24';
 }
 
+use Archive::Zip;
+
 warn(
 "Archive::Zip::Tree is deprecated; its methods have been moved into Archive::Zip."
 ) if $^W;
